{% extends base_template_name %}
{% load static %}

{% block main %}

{{ block.super }}

<div class="container bg-3 text-center">
		<h3> 
			<a href="{% url prescribe_listboard_url_name %}" class="btn btn-default btn-lg"><span class="glyphicon glyphicon-edit"></span> Prescribe</a>
		</h3>
		<h3>
			<a href="{% url dispense_listboard_url_name %}" class="btn btn-default btn-lg"><span class="glyphicon glyphicon-share"></span> Dispense</a>
		</h3>	
</div>


{% endblock main %}
