{% extends "edc_pharmacy_dashboard/listboard.html" %}

{% block panel_action_buttons %}
    <button class="btn btn-sm btn-default" type="submit" id="action" name="action" form="{{ form_action_name }}" value="approve_selected_prescription">
        Approve Selected Prescriptions
    </button>
{% endblock panel_action_buttons %}

{% block results_header %}
    {% include 'edc_pharmacy_dashboard/listboard/prescription/results_header.html' %}
{% endblock results_header %}

{% block results_body %}
    {% include 'edc_pharmacy_dashboard/listboard/prescription/results_body.html' %}
{% endblock results_body %}
