{% extends "edc_pharmacy_dashboard/listboard.html" %}

{% block results_header %}
    {% include 'edc_pharmacy_dashboard/listboard/worklist/results_header.html' %}
{% endblock results_header %}

{% block results_body %}
    {% include 'edc_pharmacy_dashboard/listboard/worklist/results_body.html' %}
{% endblock results_body %}
