
<!-- begin columns -->
    <td>
      <input id="selected_item_{{wrapped.object.id}}" form="{{ form_action_name }}" name="{{ form_action_selected_items_name }}" type="checkbox" value="{{wrapped.object.id}}"/>
    </td>
    <td>
      <span class="text text-identifier">
      {{ wrapped.object.schedule.subject_identifier }}
      </span>
    </td>
    <td>
    {% if wrapped.object.schedule.arm == 'single_dose' %} 
        Single Dose
    {% else %}
        Control
    {% endif %}
    </td>
    <td>
   <div class="btn-group">
     
      <button type="button" class="btn btn-default" title="Dispense Status">
      {% if wrapped.object.is_dispensed %}
            <span class="text text-success"><i class="fa fa-check-circle fa-lg" title="Dispensed on {{wrapped.object.appt_datetime}}"></i></span>
       {% else %}
           <span class="text text-danger"><i class="fa fa-times-circle fa-lg" title="Not dispensed"></i></span>
       {% endif %}
      </button>
      <div class="btn-group" title="View Medication list to dispense">
        <button type="button" class="btn btn-default" data-toggle="modal" data-target="#dispenseMedicationModal-{{ page_obj.start_index|add:forloop.counter0 }}">
        <i class="glyphicon glyphicon-option-vertical" aria-hidden="true"></i> <small>Prescriptions</small></button>
        {% include 'edc_pharmacy_dashboard/listboard/appointment/dispensensing_modal.html' %}
      </div>

      <a 
        {% if wrapped.can_dispense_labels %}
              href="{% url dispense_print_label_action_url_name wrapped.object.schedule.subject_identifier wrapped.appointment_id %}"
        {% else %}
            href="#"
        {% endif %}
      class="btn btn-default" role="button"
      title="Print medication labels.">
         <i class="fa fa-print" aria-hidden="true"></i>
         {{appointment_listboard_url_name}}
      </a>
      <a  class="btn btn-default" role="button" title="Go Prescription"
          href="{% url prescription_listbord_url_name wrapped.object.subject_identifier %}">
          <i class="fa fa-sitemap fa-fw"></i>
      </a>
    </div>
    </td>
     <td>
       {{wrapped.object.appt_datetime | date:"Y-m-d" }}
    </td>
    <td>
    </td>
    <td>
        {{wrapped.object.schedule.description}}
    </td>
    <td>
    <dl>
        <dt>{{wrapped.dispense_appt_describe.start_day}}</dt>
        <dd class="text text-info"><small>{{wrapped.object.appt_datetime | date:"Y-m-d"}}</small></dd>
    </dl> 
    </td>
    
    <td>
    <dl>
        <dt>{{wrapped.dispense_appt_describe.end_day}}</dt>
        <dd class="text text-info"><small>{{wrapped.dispense_appt_describe.end_date | date:"Y-m-d"}}</small></dd>
    </dl> 
    </td>

<!-- end columns -->
