{% extends base_template_name %}
{% load static %}
{% load tz %}


{% block extrastyle %}
    <link rel="stylesheet" type="text/css" href="{% static "edc_pharmacy_dashboard/css/extra.css" %}">
{{ block.super }}
{% endblock extrastyle %}


{% block main %}
<div class="container">
   <div class="row">
      <div class="col-md-12">

        {% block alert %}
        {% endblock alert %}

        <div class="panel-group">

          <div class="panel panel-success">
            <div class="panel-heading clearfix">

                   <div class="col-sm-8">   
                   {% block panel_action_form %}
                   {% endblock panel_action_form %}
                   </div>

                   <div class="col-sm-4">   
                    {% block search_form %}
                        {% include 'edc_dashboard/search_form.html' %}
                    {% endblock search_form %}
                   </div>
            </div>
          </div>
          <div class="panel-body">

            {% block results_table %}
            {% endblock results_table %}

          </div>
        </div>
      </div>
      
   </div>
</div> 

{% endblock main %}