{% load tz %}
{% load edc_dashboard_extras %}
{% load static %}

    <td style="white-space: nowrap">

	      <a role="button" title="Go Prescription" class="btn btn-sm btn-default"
	        href="{% url prescription_listboard_url_name wrapped.object.subject_identifier %}">
	            <i class="fa fa-sitemap fa-fw"></i>
	      </a>
    </td>
