
<!-- begin results body -->

{% for wrapped in object_list %}
    <tr> 
    <td>{{ forloop.counter }}</td>

    {% include 'edc_pharmacy_dashboard/listboard/worklist/buttons_column.html' %}

    {% include 'edc_pharmacy_dashboard/listboard/worklist/columns.html' %}

    </tr>                       
{% endfor %}

<!-- begin results body -->
