{% extends 'edc_pharmacy_dashboard/base_listboard.html' %}

{% load static %}


<!-- begin panel_action_form -->
{% block panel_action_form %}

    {% block panel_back %}{% endblock panel_back %}
    {% block panel_description%}{% endblock panel_description%}
    <form action="{% if form_action_url %}{{ form_action_url }}{% else %}{% url listboard_url_name %}{% endif %}" method="post" name="{{ form_action_name }}" id="{{ form_action_name }}">
     <div class="form-inline">
     <div class="input-group input-group-sm">
       
       <!-- begin panel_inputs -->
       {% block panel_inputs %}
       {% endblock panel_inputs %}
       <!-- end panel_inputs -->
    
      </div>
    
       <!-- begin panel_action_buttons -->
       {% block panel_action_buttons %}                   
       {% endblock panel_action_buttons %}
       <!-- end panel_action_buttons -->
    
    
       <!-- begin panel_action_hidden -->
       {% block panel_action_hidden %}                   
           <input type="hidden" id="box_identifier" name="box_identifier" value="{{ box_identifier }}" />
           {% csrf_token %}
       {% endblock panel_action_hidden %}
       <!-- end panel_action_hidden -->
    
      </div>
    </form>
    
{% endblock panel_action_form %}
<!-- end panel_action_form -->

{% block results_table %}
  <!--start results-->
    <div class="form-group">

       {% block results_panel_form %}
       {% endblock results_panel_form %}
    
      <div class="table table-responsive">
        <table class="table table-condensed table-hover small">
          <thead>

            {% block results_header %}
                {% include 'edc_pharmacy_dashboard/listboard/prescription/results_header.html' %}
            {% endblock results_header %}

          </thead>
          <tbody>

            {% block results_body %}
                {% include 'edc_pharmacy_dashboard/listboard/prescription/results_body.html' %}
            {% endblock results_body %}
          </tbody>
        </table>
            <!-- has_next_page or has_previous then show -->
            {% include 'edc_dashboard/paginator.html' %}
      </div>
  </div>

	{% if not results %}
	    <span class="alert alert-success"><i class="fa fa-thumbs-o-up fa-fw"></i> {{ empty_queryset_message }}</span>
	{% endif %}
  <!--end results-->
{% endblock results_table %}
