{% load tz %}
{% load edc_dashboard_extras %}
{% load static %}


<!--  begin columns  -->
    <td></td>
	<td></td>
	<td></td>
    <td>{{wrapped.object.subject_identifier}}</td>
    <td>{{wrapped.object.enrollment_datetime| date:"Y-m-d" }}</td>
    <td>
        {{wrapped.object.next_dispensing_datetime | date:"Y-m-d"}}
    </td>   
	<td>
	  {% for status in wrapped.appointments %}
		  {% if status %}
	        <span class="text text-success"><i class="fa fa-check-circle fa-fw" title="Approved"></i></span>
	      {% else %}
	        <span class="text text-danger"><i class="fa fa-times-circle fa-fw" title="Not Approved"></i></span>
	      {% endif %}
	   {% endfor %}
	</td>
<!--  end columns  -->
