
{% for wrapped in object_list %}
  <!-- result is a ModelWithLogEntry wrapper -->
  <tr>
    <!--counter-->
    <td>{{ page_obj.start_index|add:forloop.counter0 }}</td>
    <!--buttons-->
     {% include 'edc_pharmacy_dashboard/listboard/prescription/columns.html' %}
  </tr>
{% endfor %}
